define([
  "dojo/_base/declare",
  "dojo/when",
  "dojox/mvc/getPlainValue",
  "dojox/mvc/at",
  "dojox/mvc/getStateful",
  "aps/View",
  "aps/ResourceStore",
  "aps/json!./wizard/newvps.json",
  "./displayError"
], function (declare, when, getPlainValue, at, getStateful, View, Store,
	newVPS, displayError) {
	return declare(View, {
		init: function () {
			
			this.vpsModel = getStateful({"data": newVPS});
			
			/* Define and return widgets */
			return ["aps/Panel", {id: this.genId("edit_form")}, [
				["aps/FieldSet", {
						title: "General"
					},
					[
						["aps/TextBox", {
							label: "Server Name",
							value: at(this.vpsModel.data, "vpsname"),
							required: true
						}],
						["aps/TextBox", {
							label: "Description",
							value: at(this.vpsModel.data, "description")
						}]
					]
				],
				["aps/FieldSet", {
						title: "Server Configuration"
					},
					[
						["aps/Spinner", {
							label: "CPU Number",
							minimum: 1,
							maximum: 16,
							value: at(this.vpsModel.data.hardware.CPU, "number"),
							step: 1
						}],
						["aps/Spinner", {
							label: "Disk Space",
							minimum: 1,
							maximum: 100,
							value: at(this.vpsModel.data.hardware, "diskspace"),
							legend: "Gb",
							step: 1
						}],
						["aps/Spinner", {
							label: "RAM",
							minimum: 128,
							maximum: 8192,
							value: at(this.vpsModel.data.hardware, "memory"),
							legend: "Mb",
							step: 128
						}]
				]]
			]];
		},
		
		/* Define handlers for the navigation buttons */
		onCancel: function() {
			aps.apsc.gotoView("servers");
		},
		onSubmit: function() {
		    var form = this.byId("edit_form");
		    if (!form.validate()) {
		       aps.apsc.cancelProcessing();
		       return;
		    }
			/* Declare data sources */
			var store = new Store({
				target: "/aps/2/resources"
			});
		    when(store.put(getPlainValue(this.vpsModel.data)),
		       function() {
		          aps.apsc.gotoView("servers");
		       },
		       displayError
		    );
		},
		
		/* Define the view flow methods */
		onContext: function() {
	        /* Update the model with actual data from the navigation variable */
	        this.vpsModel.set("data", aps.context.vars.vps);
	        aps.apsc.hideLoading(); /* Mandatory call */
		}
	});
});
