define([
   "dojo/_base/declare",
   "dojo/when",
   "aps/View",
   "aps/xhr",
   "aps/ResourceStore",
   "./displayError"
], function (declare, when, View, xhr, Store, displayError) {
   var subscriptionId;

   function createDnsRecord(vps) {
	   var jsonData = {
	      "aps": {
	         "type": "http://aps-standard.org/types/dns/record/a/1.0"
	      },
	      "RRState": "active",
	      "TTL": 3600,
	      "source": vps.domainName + ".",
	      "address": vps.ipAddress,
	      "zone": {
	         "aps": {
	            "id": vps.domain.aps.id
	         }
	      }
	   };
	   return xhr("/aps/2/resources/" + vps.aps.id + "/records", {
	      method: "POST",
	      data: JSON.stringify(jsonData)
	   });
   }
   
   return declare(View, {
      init: function() {
         /* Display explanations about the process driven by the wizard */
		return ["aps/Panel", {
			id: "wizard_panel"
		},
		[["aps/Output", {
			id: "wizard_contents",
			content: "<h2>Let's create one more server </h2>"  +
			"Before getting started, make sure you have all necessary parameters: <br>" +
			"<ul> <li> CPU power - number of CPU cores" +
			"<li> Disk space - GB" +
			"<li> RAM space - MB"
		}]]];
      },

      onContext: function(context) {
			/* Make all views plugged into the wizard visible */
			subscriptionId = context.vars.context.aps.subscription;
			aps.context.wizardState.forEach(function(view) {
					view.visible = true;
				}
			);
			aps.apsc.wizardState(aps.context.wizardState);
			aps.apsc.hideLoading();
      },

      onNext: function() {
			/* Direct a user to the first view */
			if (aps.context.params.domainApsId) { // If we've come here from the DNS Manager
				aps.apsc.next(aps.context.params.domainApsId);
			}
			else aps.apsc.next();
      },

      onSubmit: function() {
			/* Specify the subscription whose resource will be used */
			aps.context.subscriptionId = subscriptionId;

			/* Create the data store */
			var store = new Store({
				apsType: "http://aps-standard.org/samples/bind2domain/vps/1.0",
				target: "/aps/2/resources/"
			});

			/* Receive data from the 1st view and save the new VPS */
			var newVPS =
				aps.context.wizardData["http://aps-standard.org/samples/bind2domain#server-new-1"];
			store.put(newVPS)
			.then(function(vps) {
				return createDnsRecord(vps);
			})
			.then(function() {
					aps.apsc.gotoView("servers");
				}, displayError
			);
	  },

      onCancel: function() {
			/* Forward a user to the list of servers */
			aps.apsc.gotoView("servers");
      }

   });
});
