define([
   "dojo/_base/declare",
   "dojox/mvc/at",
   "dojox/mvc/getStateful",
   "aps/View",
   "aps/ResourceStore",
   "aps/Memory",
   /* Include JSON file that defines the VPS default properties */
   "aps/json!./newvps.json"
],
function (declare, at, getStateful, View, Store, Memory, newVPS) {
	return declare(View, {
		init: function() {
	
			/* Declare data sources */
		    this.domainStore = new Memory({
		        data: [],
		        idProperty: "aps.id"
		     });
			var oses = new Memory({
			    idProperty: "value",
			       data: [
			          { value: "centos6",      label: "CentOS 6" },
			          { value: "centos7",      label: "CentOS 7" },
			          { value: "debian",       label: "Debian" },
			          { value: "windows2008",  label: "Windows 2008 Server" },
			          { value: "windows2012",  label: "Windows 2012 Server" }
			       ]
			});
			this.vpsModel = getStateful({"data": newVPS});
			
			/* Define and return widgets */
			return ["aps/Panel", { id: this.genId("srvNew_form") }, [
				["aps/FieldSet", { title: "General" }, [
					["aps/TextBox", {
						label: "Server Name",
						value: at(this.vpsModel.data, "vpsname"),
						required: true
					}],
					["aps/TextBox", {
						label: "Description",
						value: at(this.vpsModel.data, "description")
					}]
				]],
				["aps/Panel", { id: this.genId("srvNew1_vps_configuration"), title: "Server Configuration" }, [
		           ["aps/FieldSet", { id: this.genId("srvNew1_config") }, [
		                ["aps/Select", {
		                    label: "OS",
							gridSize: 'md-3 xs-12',
		                    value: at(this.vpsModel.data.platform.OS, "name"),
		                    store: oses
		                }],
		                ["aps/Spinner", {
		                    label:  "CPU Number",
							gridSize: 'md-3 xs-12',
		                    minimum: 1,
		                    maximum: 16,
		                    value: at(this.vpsModel.data.hardware.CPU, "number"),
		                    step: 1
		                }],
		                ["aps/Spinner", {
		                    label: "Disk Space",
							gridSize: 'md-3 xs-12',
		                    minimum: 1,
		                    maximum: 100,
		                    value: at(this.vpsModel.data.hardware, "diskspace"),
		                    legend: "Gb",
		                    step: 1
		                }],
		                ["aps/Spinner", {
		                    label: "RAM",
							gridSize: 'md-3 xs-12',
		                    minimum: 128,
		                    maximum: 8192,
		                    value: at(this.vpsModel.data.hardware, "memory"),
		                    legend: "Mb",
		                    step: 128
		                }]
		           ]]
	           ]],
	           ["aps/FieldSet", { id: this.genId("srvNew1_domains") }, [
					["aps/Select", {
						id: this.genId("srvNew1_domainSelect"),
						label: "Domain",
						gridSize: 'md-3 xs-12',
						store: this.domainStore,
						labelAttr: "name",
						value: at(this.vpsModel.data.domain.aps, "id"),
						required: true
					}],
			        ["aps/TextBox", {
			             id: this.genId("srvNew1_ipAddress"),
			             label: "IP Address",
			             gridSize: "md-3 xs-12",
			             value: at(this.vpsModel.data, "ipAddress"),
			             required: true
			        }]
				]]
	        ]];
		},

		/* Additional single-page view flow method */
		onContext: function(context) {
			if (!aps.context.wizardData["http://aps-standard.org/samples/bind2domain#server-new-1"])
				this.vpsModel.set("data", newVPS);
	             
			/* Refresh the store */
			var domains = context.vars.context.paDomains;
			this.domainStore.setData(domains);
			var domainSelection = this.byId("srvNew1_domainSelect");
			domainSelection.set("store", this.domainStore);
	             
            /* Define the selected domain */
			if (aps.context.wizardData["http://aps-standard.org/samples/bind2domain#vps-wizard"]) {
				this.vpsModel.data.domain.aps.set(
					"id",
					aps.context.wizardData["http://aps-standard.org/samples/bind2domain#vps-wizard"]
				);
			}
			else domainSelection.set("value", domains[0].aps.id);
             
            aps.apsc.hideLoading();
	    },

		/* Create handlers for the navigation buttons */
		onNext: function() {
		    
			var form = this.byId("srvNew_form");
	
		    /* Validate the values assigned to widgets */
		    if (!form.validate()) {
		       aps.apsc.cancelProcessing();
		       return;
		    }
		    
		    /* Figure out the VPS domain name */
		    var selectWidget = this.byId("srvNew1_domainSelect");
		    var domainId = selectWidget.get("value");
		    this.vpsModel.data.set(
				"domainName",
				this.vpsModel.data.vpsname + "." + selectWidget.getOption(domainId)[0].label
			);
	
		    /* Proceed to the next step */
		    aps.apsc.next(this.vpsModel.data);
		},
		onPrev: function() {
			aps.apsc.prev();
		}
	
	});
});
